local GT = AceLibrary("Gratuity-2.0")
local Deformat = AceLibrary("Deformat-2.0")		
		
local tierSets = {}
local armorSets = {
	DRUID = { "Nordrassil Raiment", "Nordrassil Regalia", },
	MAGE = { "Tirisfal Armor", },
	PALADIN = { "Justicar Armor", "Justicar Battlegear", "Crystalforge Raiment", },
	PRIEST = { "Hallowed Raiment", "Incarnate Regalia", "Incarnate Raiment", },
	SHAMAN = { "Tidefury Raiment", "Cataclysm Raiment", "The Ten Storms", },
	WARLOCK = { "Oblivion Raiment", "Voidheart Raiment", "Corruptor Raiment", "Plagueheart Raiment" },
}

local armorSetsFR = {
	DRUID = { "Grande Tenue de Nordrassil", "Tenue de Parade de Nordrassil", },
	MAGE = { "Tenue de Parade de Tirisfal", },
	PALADIN = { "Armure de Justicier", "Tenue de combat de Justicier", "Grande Tenue de Cristalforge", },
	PRIEST = { "Grande Tenue B\195\169nie", "Tenue de Parade des Incarn\195\169s", "Grande Tenue des Incarn\195\169s", },
	SHAMAN = { "Grande Tenue du Mascaret", "Grande Tenue du Cataclysme", "Les Dix Temp\195\170tes", },
	WARLOCK = { "Grande Tenue de l'Oubli", "Grande Tenue du Coeur-du-Vide", "Grande Tenue de Corrupteur", "Grande Tenue de Pestecoeur", },
}

local armorSetsKR = {
	DRUID = { "놀드랏실 예복", "놀드랏실 의복", },
	MAGE = { "티리스팔 의복", },
	PALADIN = { "정화의 갑옷", "정화의 전투장비", "정화의 예복", },
	PRIEST = { "신성의 예복", "현신의 의복", "현신의 예복", },
	SHAMAN = { "천재지변의 의복", "천재지변의 예복", "폭풍우 방어구", },
	WARLOCK = { "망각의 수의", "공허의심장 의복", "타락자의 의복", "역병의심장 의복" },
}

local _, englishClass = UnitClass("player")

function DrDamage:ItemSets()

	local setTable
	
	if GetLocale() == "enUS" or GetLocale() == "enGB" then
		setTable = armorSets[englishClass]
	elseif GetLocale() == "frFR" then
		setTable = armorSetsFR[englishClass]
	elseif GetLocale() == "koKR" then
		setTable = armorSetsKR[englishClass]
	end
	
	if not setTable then
		do return end
	end

	for k in ipairs( tierSets ) do
		tierSets[k] = nil
	end
	
	for i = 1, 12 do
		local link = GetInventoryItemLink( "player", i )
		if link then 
			GT:SetHyperlink( link )
			for j = 2, GT:NumLines() do
				local setName, setAmount = Deformat(GT:GetLine(j), ITEM_SET_NAME)
				if setName then
					for tier, set in ipairs( setTable ) do
						if setName == set then
							tierSets[tier] = setAmount
						end
					end					
				end
			end
		end
	end
	
	for i = 1, 4 do
		if not tierSets[i] then
			tierSets[i] = 0
		end
	end
end

function DrDamage:SetBonuses( spellName, eDuration, finalMod, dmgM, castTime, chainFactor, jotcBonus, debuffBonus )

	local b1, b2, b3, b4 = unpack( tierSets )

	if englishClass == "DRUID" then
		if b1 then
			if b1 >= 2 then
				if spellName == "Regrowth" then
					eDuration = eDuration + 6
				end

				if b1 >= 4 then
					if spellName == "Lifebloom" then
						finalMod = finalMod + 150
					end
				end
			end
		end
		if b2 then
			if b2 >= 4 then
				if debuffBonus then
					dmgM = dmgM * 1.1
				end
			end
		end
	elseif englishClass == "MAGE" then
		if b1 then
			if b1 >= 2 then
				if spellName == "Arcane Blast" then
					dmgM = dmgM * 1.2
				end
			end
		end
	elseif englishClass == "PALADIN" then
		if b1 then
			if b1 >= 4 then
				if spellName == "Holy Shield" then
					dmgM = dmgM * 1.15
				end
			end
		end
		if b2 then
			if b2 >= 2 then
				if jotcBonus then
					jotcBonus = jotcBonus * 1.15
				end
			end
			if b2 >= 4 then
				if spellName == "Seal of Command" then
					dmgM = dmgM * 1.1
				end
			end
		end
		if b3 then
			if b3 >= 4 then
				if spellName == "Holy Light" then
					castTime = castTime - 0.2
				end
			end
		end
	elseif englishClass == "PRIEST" then
		if b1 then
			if b1 >= 4 then
				if spellName == "Prayer of Mending" then
					finalMod = finalMod + 100
				end
			end
		end
		if b2 then
			if b2 >=4 then
				if spellName == "Smite" or spellName == "Mind Flay" then
					dmgM = dmgM * 1.05
				end
			end
		end
		--[[
		if b3 then
			if b2 >= 2 then
				if spellName == "Prayer of Healing" then
					2: Your Prayer of Healing spell now also causes an additional 150 healing over 9 seconds.
				end
			end
		end
		--]]

	elseif englishClass == "SHAMAN" then
		if b1 then
			if b1 >= 2 then
				if spellName == "Chain Lightning" then
					chainFactor = chainFactor + 0.13
				end
			end
		end
		if b2 then
			if b2 >= 4 then
				if spellName == "Healing Wave" then
					castTime = castTime - 0.25
				end
			end
		end
		if b3 then
			if b3 >= 3 then
				if spellName == "Chain Heal" then
					chainFactor = chainFactor + 0.3
				end
			end
		end
	elseif englishClass == "WARLOCK" then
		if b1 then
			if b1 >= 4 then
				if spellName == "Seed of Corruption" then
					finalMod = finalMod + 180
				end
			end
		end
		if b2 then
			if b2 >= 4 then
				if spellName == "Corruption" or spellName == "Immolate" then
					eDuration = eDuration + 3
				end
			end
		end
		if b4 then
			if b4 >= 4 then
				if spellName == "Corruption" then
					dmgM = dmgM * 1.12
				end
			end
		end
	end
	
	return eDuration, finalMod, dmgM, castTime, chainFactor, jotcBonus
end


DrDamage.RelicSlot = {
		["Chain Heal"] = { 28523, 87, ModType1 = "Base" }, 						--Totem of Healing Rains (Epic)
		["Healing Wave"] = { 27544, 88, },								--Totem of Spontaneous Regrowth
		["Lesser Healing Wave"] = { 25645, 79, 22396, 80, 23200, 53 },					--Totem of the Plains, Totem of Life, Totem of Sustaining
		["Rejuvenation"] = { 25643, 86, 22398, 50, },							--Harold's Rejuvenating Broach, Idol of Rejuvenation
		["Lifebloom"] = { 27886, 88, 28355, 87, ModType1 = "Dot", ModType2 = "Final" },			--Idol of the Emerald Queen, Idol of Tenacity
		["Healing Touch"] = { 28568, 136, 22399, 100, ModType1 = "Final", ModType2 = "Final" },		--Idol of the Avian Heart, Idol of Health
		["Flash of Light"] = { 23006, 83, 25644, 79, 23201, 53, },					--Libram of Light, Blessed Book of Nagrand, Libram of Divinity
		["Holy Light"] = { 28296, 87, },								--Libram of the Lightbringer
		["Earth Shock"] = { 22395, 30, 27947, 46, 27984, 46, },						--Totem of Rage, Totem of Impact
		["Frost Shock"] = { 22395, 30, 27947, 46, 27984, 46, },						--Totem of Rage, Totem of Impact
		["Flame Shock"] = { 22395, 30, 27947, 46, 27984, 46, },						--Totem of Rage, Totem of Impact
		["Lightning Bolt"] = { 28248, 55, 23199, 33 },							--Totem of the Void, Totem of the Storm
		["Chain Lightning"] = { 28248, 55, 23199, 33 },							--Totem of the Void, Totem of the Storm
		["Moonfire"] = { 23197, 33 }, 									--Idol of the Moon
		["Starfire"] = { 27518, 55 },									--Ivory Idol of the Moongoddess
		["Consecration"] = { 27917, 47 },								--Libram of the Eternal Rest
		["Crusader Strike"] = { 31033, 18, ModType1 = "Final" },					--Libram of Righteous Power
		["Wrath"] = { 31025, 25 },									--Idol of the Avenger
}	